@@ -10,7 +10,7 @@ use base qw( Data::Page Class::Data::Inheritable );
 
 use vars qw( $VERSION );
 
-$VERSION = 0.55;
+$VERSION = 0.56;
 
 # D::P inherits from Class::Accessor::Chained::Fast
 __PACKAGE__->mk_accessors( qw( where abstract_attr per_page page order_by _cdbi_app ) );
@@ -94,14 +94,15 @@ sub import {
 
     my $caller;
 
-    # find the app
+    # find the app - supports subclassing (My::Pager is_a CDBI::P::Pager, not_a CDBI)
     foreach my $level ( 0 .. 10 )
     {
         $caller = caller( $level );
         last if UNIVERSAL::isa( $caller, 'Class::DBI' )
     }
 
-    croak( "can't find the CDBI app" ) unless $caller;
+    warn( "can't find the CDBI app" ), return unless $caller; 
+    #croak( "can't find the CDBI app" ) unless $caller;
 
     no strict 'refs';
     *{"$caller\::pager"} = \&pager;
